==> gatsby-advanced-blog-1.1.1.tgz: package/CHANGELOG.md <==
# Changelog

## TODO
- [ ] use typescript for typing

## 1.1.0 - 2019-04-07
- [x] add theming features

## 1.0.0 - 2019-04-06
- [x] update packages (React, Gatsby, etc.)
- [x] use hooks instead of redux

## 0.2.3 - 2018-09-26
- [x] update `gatsby` version (`v2.0.8`)

## 0.2.2 - 2018-08-24
- [x] fix issue that is related with media query for print ((ISSUE 11)[https://github.com/wonism/gatsby-advanced-blog/issues/11])

## 0.2.1 - 2018-08-10
- [x] update `gatsby` to use `Link` in `gatsby` instead of `gatsby-link` ((ISSUE 8)[https://github.com/wonism/gatsby-advanced-blog/issues/8])
- [x] remove all `css`s and add styles into `Styled Components`. ((ISSUE 9)[https://github.com/wonism/gatsby-advanced-blog/issues/9])
- [x] fix SSR ((ISSUE 9)[https://github.com/wonism/gatsby-advanced-blog/issues/9])
- [x] update `.eslintrc` to change some rules

## 0.2.0-1 - 2018-07-22
- [x] add `LICENCE.md`

## 0.2.0 - 2018-07-08
- [x] migrate `gatsby` into `v2 beta` (from `v2 alpha`)
  - [x] add `gatsby` with specific `version` into `peerDependencies`
- [x] use `css` instead of `less`
- [x] update `dependencides`
  - [x] `babel`, `redux`, `react` etcetera

## 0.1.9 - 2018-04-22
- [x] fix bug (post's html)
- [x] remove console
- [x] change eslint rules

## 0.1.7 - 2018-04-22
- [x] fix bug (related with `styled-components`)
- [x] change logics for adding image into post
- [x] add `react-helmet` into some pages
- [x] change some styles
  - [x] add font(`Inconsolata`) for `<code>`'s `font-family`

## 0.1.6 - 2018-04-14
- [x] fix lint
- [x] add husky for hooking commit

## 0.1.5 - 2018-04-06
- [x] remove `height: 100vh;`

## 0.1.4 - 2018-04-05
- [x] fix ui bug in production mode

## 0.1.3 - 2018-04-04
- [x] add image to post
- [x] add copy button in post
- [x] add `border-radius` to profile image
- [x] fix card UI (tags are overflowed)
- [x] improve post readablity
- [x] move logics for rendering tweets & components into `redux-saga`

## 0.1.2-alpha - 2018-04-03
- [x] update `READEME.md`
- [x] customize `404` page
- [x] add `min-height` to contents wrapper

## 0.1.1-alpha - 2018-04-03
- [x] support mobile version

## 0.1.0-alpha - 2018-03-29
- [x] initial commit
- [x] features
  - [x] Post
    - [x] Pagination
    - [x] Categories
    - [x] Tags
    - [x] Search
    - [x] Put React Application into post
    - [x] Put Tweet into post
    - [x] Draft (set `hide` to `true`)
  - [x] Portfolio
  - [x] Resume

==> gatsby-advanced-blog-1.1.2.tgz: package/CHANGELOG.md <==
# Changelog

## TODO
- [ ] use typescript for typing

## 1.1.2 - 2019-04-07
- [x] fix ui bug (dropdown in GNB)

## 1.1.1 - 2019-04-07
- [x] add theming features

## 1.0.0 - 2019-04-06 (unpublished)
- [x] update packages (React, Gatsby, etc.)
- [x] use hooks instead of redux

## 0.2.3 - 2018-09-26
- [x] update `gatsby` version (`v2.0.8`)

## 0.2.2 - 2018-08-24
- [x] fix issue that is related with media query for print ((ISSUE 11)[https://github.com/wonism/gatsby-advanced-blog/issues/11])

## 0.2.1 - 2018-08-10
- [x] update `gatsby` to use `Link` in `gatsby` instead of `gatsby-link` ((ISSUE 8)[https://github.com/wonism/gatsby-advanced-blog/issues/8])
- [x] remove all `css`s and add styles into `Styled Components`. ((ISSUE 9)[https://github.com/wonism/gatsby-advanced-blog/issues/9])
- [x] fix SSR ((ISSUE 9)[https://github.com/wonism/gatsby-advanced-blog/issues/9])
- [x] update `.eslintrc` to change some rules

## 0.2.0-1 - 2018-07-22
- [x] add `LICENCE.md`

## 0.2.0 - 2018-07-08
- [x] migrate `gatsby` into `v2 beta` (from `v2 alpha`)
  - [x] add `gatsby` with specific `version` into `peerDependencies`
- [x] use `css` instead of `less`
- [x] update `dependencides`
  - [x] `babel`, `redux`, `react` etcetera

## 0.1.9 - 2018-04-22
- [x] fix bug (post's html)
- [x] remove console
- [x] change eslint rules

## 0.1.7 - 2018-04-22
- [x] fix bug (related with `styled-components`)
- [x] change logics for adding image into post
- [x] add `react-helmet` into some pages
- [x] change some styles
  - [x] add font(`Inconsolata`) for `<code>`'s `font-family`

## 0.1.6 - 2018-04-14
- [x] fix lint
- [x] add husky for hooking commit

## 0.1.5 - 2018-04-06
- [x] remove `height: 100vh;`

## 0.1.4 - 2018-04-05
- [x] fix ui bug in production mode

## 0.1.3 - 2018-04-04
- [x] add image to post
- [x] add copy button in post
- [x] add `border-radius` to profile image
- [x] fix card UI (tags are overflowed)
- [x] improve post readablity
- [x] move logics for rendering tweets & components into `redux-saga`

## 0.1.2-alpha - 2018-04-03
- [x] update `READEME.md`
- [x] customize `404` page
- [x] add `min-height` to contents wrapper

## 0.1.1-alpha - 2018-04-03
- [x] support mobile version

## 0.1.0-alpha - 2018-03-29
- [x] initial commit
- [x] features
  - [x] Post
    - [x] Pagination
    - [x] Categories
    - [x] Tags
    - [x] Search
    - [x] Put React Application into post
    - [x] Put Tweet into post
    - [x] Draft (set `hide` to `true`)
  - [x] Portfolio
  - [x] Resume
